aboutsummaryrefslogtreecommitdiffstats
path: root/build.gradle
diff options
context:
space:
mode:
Diffstat (limited to 'build.gradle')
-rw-r--r--build.gradle4
1 files changed, 2 insertions, 2 deletions
diff --git a/build.gradle b/build.gradle
index 178bbbb26..0f2e968b2 100644
--- a/build.gradle
+++ b/build.gradle
@@ -36,8 +36,8 @@ subprojects {
}
}
-// Ignore tests for external spongycastle
-project(':extern:spongycastle') {
+// Ignore tests for external bouncycastle
+project(':extern:bouncycastle') {
subprojects {
// Need to re-apply the plugin here otherwise the test property below can't be set.
apply plugin: 'java'